package com.muyu.net.working.controller;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysDept;
import com.muyu.common.system.domain.SysUser;
import com.muyu.system.remote.RemoteSysDeptService;
import com.muyu.system.remote.RemoteSysUserService;
import com.muyu.system.remote.factory.RemoteSysDeptFactory;
import io.swagger.annotations.*;
import io.swagger.models.auth.In;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.net.working.domain.Enterprise;
import com.muyu.net.working.domain.req.EnterpriseQueryReq;
import com.muyu.net.working.domain.req.EnterpriseSaveReq;
import com.muyu.net.working.domain.req.EnterpriseEditReq;
import com.muyu.net.working.service.EnterpriseService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 车辆运营平台Controller
 *
 * @author muyu
 * @date 2024-06-05
 */
@Api(tags = "车辆运营平台")
@Log4j2
@RestController
@RequestMapping("/car")
public class EnterpriseController extends BaseController {
    @Autowired
    private EnterpriseService enterpriseService;

    @Autowired
    private RemoteSysDeptService remoteSysDeptService;
    @Autowired
    private RemoteSysUserService remoteSysUserService;

    /**
     * 查询车辆运营平台列表
     */
    @ApiOperation("获取车辆运营平台列表")
    @RequiresPermissions("netWorking:car:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Enterprise>> list(EnterpriseQueryReq enterpriseQueryReq) {
        startPage();
        List<Enterprise> list = enterpriseService.list(Enterprise.queryBuild(enterpriseQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出车辆运营平台列表
     */
    @ApiOperation("导出车辆运营平台列表")
    @RequiresPermissions("netWorking:car:export")
    @Log(title = "车辆运营平台", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Enterprise enterprise) {
        List<Enterprise> list = enterpriseService.list(enterprise);
        ExcelUtil<Enterprise> util = new ExcelUtil<Enterprise>(Enterprise.class);
        util.exportExcel(response, list, "车辆运营平台数据");
    }

    /**
     * 获取车辆运营平台详细信息
     */
    @ApiOperation("获取车辆运营平台详细信息")
    @RequiresPermissions("netWorking:car:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class)
    public Result<Enterprise> getInfo(@PathVariable("id") String id) {
        return Result.success(enterpriseService.getById(id));
    }

    /**
     * 新增车辆运营平台
     */
    @RequiresPermissions("netWorking:car:add")
    @Log(title = "车辆运营平台", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增车辆运营平台")
    public Result<String> add(@RequestBody EnterpriseSaveReq enterpriseSaveReq) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser sysUser = loginUser.getSysUser();
        Result<SysDept> DeptList = remoteSysDeptService.selectDeptByName(enterpriseSaveReq.getEbterpriseName());
        SysDept sysDept = DeptList.getData();
        if(sysDept!=null){
            return Result.error("部门名称重复");
        }
        addDept(enterpriseSaveReq, sysUser);
        addUser(enterpriseSaveReq,sysUser);

        return toAjax(enterpriseService.save(Enterprise.saveBuild(enterpriseSaveReq)));
    }

    /**
     * 添加部门表信息
     * @param enterpriseSaveReq
     * @param sysUser
     * @return
     */
    public void addDept(EnterpriseSaveReq enterpriseSaveReq,SysUser sysUser){

        SysDept DeptBuild = SysDept.builder()
                .deptName(enterpriseSaveReq.getEbterpriseName())
                .parentId(100L)
                .ancestors("0,100")
                .orderNum(2)
                .status("0")
                .createBy(sysUser.getUserName())
                .createTime(new Date())
                .leader(sysUser.getNickName())
                .phone(sysUser.getPhonenumber())
                .email(sysUser.getEmail())
                .delFlag("0")
                .build();
       remoteSysDeptService.add(DeptBuild);
    }

    public void addUser(EnterpriseSaveReq enterpriseSaveReq,SysUser sysUser){
        Result<SysDept> sysDeptResult = remoteSysDeptService.selectDeptByName(enterpriseSaveReq.getEbterpriseName());
        SysDept sysDept = sysDeptResult.getData();
        SysUser UserBuild = SysUser.builder()
                .userName(enterpriseSaveReq.getEbterpriseName())
                .nickName(enterpriseSaveReq.getEbterpriseName())
                .password("123456")
                .deptId(sysDept.getDeptId())
                .email(enterpriseSaveReq.getEmail())
                .phonenumber(enterpriseSaveReq.getContactPhone())
                .status("0")
                .delFlag("0")
                .roleId(3L)
                .roleIds(new Long[]{3L})
                .createBy(sysUser.getUserName())
                .createTime(new Date())
                .remark(enterpriseSaveReq.getRemark())
                .build();
        remoteSysUserService.add(UserBuild);
    }

    /**
     * 修改车辆运营平台
     */
    @RequiresPermissions("netWorking:car:edit")
    @Log(title = "车辆运营平台", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改车辆运营平台")
    public Result<String> edit(@PathVariable String id, @RequestBody EnterpriseEditReq enterpriseEditReq) {
        return toAjax(enterpriseService.updateById(Enterprise.editBuild(id,enterpriseEditReq)));
    }

    /**
     * 查询运营平台列表
     */
    @GetMapping("/selectByName")
    public Result<Enterprise> selectByName() {
        String name = SecurityUtils.getUsername();
        Enterprise enterprise = enterpriseService.selectByName(name);
        return Result.success(enterprise);
    }
    /**
     * 删除车辆运营平台
     */
    @RequiresPermissions("netWorking:car:remove")
    @Log(title = "车辆运营平台", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除车辆运营平台")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "String", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<String> ids) {

        return toAjax(enterpriseService.removeBatchByIds(ids));
    }
}
